==> Paws-0.35.tar.gz: Paws-0.35/lib/Paws/Glue/DeleteCrawler.pm <==

package Paws::Glue::DeleteCrawler;
  use Moose;
  has Name => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteCrawler');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Glue::DeleteCrawlerResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Glue::DeleteCrawler - Arguments for method DeleteCrawler on Paws::Glue

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteCrawler on the 
AWS Glue service. Use the attributes of this class
as arguments to method DeleteCrawler.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteCrawler.

As an example:

  $service_obj->DeleteCrawler(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> Name => Str

Name of the C<Crawler> to remove.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteCrawler in L<Paws::Glue>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.38.tar.gz: Paws-0.38/lib/Paws/Glue/DeleteCrawler.pm <==

package Paws::Glue::DeleteCrawler;
  use Moose;
  has Name => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteCrawler');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Glue::DeleteCrawlerResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Glue::DeleteCrawler - Arguments for method DeleteCrawler on L<Paws::Glue>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteCrawler on the
L<AWS Glue|Paws::Glue> service. Use the attributes of this class
as arguments to method DeleteCrawler.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteCrawler.

=head1 SYNOPSIS

    my $glue = Paws->service('Glue');
    my $DeleteCrawlerResponse = $glue->DeleteCrawler(
      Name => 'MyNameString',

    );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/glue/DeleteCrawler>

=head1 ATTRIBUTES


=head2 B<REQUIRED> Name => Str

Name of the crawler to remove.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteCrawler in L<Paws::Glue>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
